@@ -29,12 +29,12 @@ class ConfigLogging(Config):
     )
 
 
-class ConfigDebugRequests(Config):
+class ConfigDebugUrls(Config):
     """
-    Configure how to user the requests module
+    Configure how to debug urls
     """
-    debug = ParamCreator.create_bool(
-        help_string="Do you want to debug the requests module?",
+    save = ParamCreator.create_bool(
+        help_string="Do you want to save urls?",
         default=False,
     )
 
@@ -159,3 +159,21 @@ class ConfigUrl(Config):
     url = ParamCreator.create_str(
         help_string="url to download (e.g. https://www.pornhub.com/model/lily)"
     )
+
+
+class ConfigRequests(Config):
+    """
+    Parameters to config the requests module
+    """
+    connect_timeout = ParamCreator.create_int_or_none(
+        help_string="Timeout for connections in seconds (none means endless)",
+        default=5,
+    )
+    read_timeout = ParamCreator.create_int_or_none(
+        help_string="Timeout for reading in seconds (none means endless)",
+        default=5,
+    )
+    debug = ParamCreator.create_bool(
+        help_string="Do you want to debug the requests module?",
+        default=False,
+    )
