@@ -3,12 +3,10 @@ This module is s set of utilities for this entire project
 """
 
 
-import http.client
 import logging
 import os
 import shutil
 import urllib.parse
-from typing import List
 
 import requests
 import lxml
@@ -39,7 +37,10 @@ def get_http_status_string(code: int):
     :param code:
     :return:
     """
-    return "http code [{}], [{}]".format(code, requests.status_codes.codes[code][0])
+    # noinspection PyProtectedMember,PyUnresolvedReferences
+    # pylint: disable=protected-access
+    return f"http code [{code}], [{requests.status_codes._codes[code][0]}]"
+    # return f"http code [{code}], [{http.client.responses[code]}]"
 
 
 def get_html_dom_content(response):
@@ -48,56 +49,12 @@ def get_html_dom_content(response):
     :param response:
     :return:
     """
-    assert response.status_code == 200, get_http_status_string(response.status_code)
+    response.raise_for_status()
     str_content = response.content.decode()
     root = lxml.html.fromstring(str_content)
     return root
 
 
-def download_urls(session, urls: List[str], start=0):
-    """
-    Download a list of urls
-    :param session:
-    :param urls:
-    :param start:
-    :return:
-    """
-    logger = logging.getLogger(__name__)
-    counter = start
-    logger.info('got [%d] real urls', len(urls))
-    for url in urls:
-        parse_result = urllib.parse.urlparse(url)
-        path = parse_result.path
-        logger.info('downloading [%s]...', url)
-        response = session.get(url, stream=True)
-        assert response.status_code == 200, response.content
-
-        filename = None
-        if path.endswith(".jpg"):
-            filename = 'image{0:04}.jpg'.format(counter)
-        if path.endswith(".mp4"):
-            filename = 'video{0:04}.mp4'.format(counter)
-        if filename is None:
-            logger.error('do not know how to handle path [%s]...', path)
-            continue
-        assert not os.path.isfile(filename), "already have filename {}".format(path)
-        with open(filename, 'wb') as file_handle:
-            response.raw.decode_content = True
-            shutil.copyfileobj(response.raw, file_handle)
-        logger.info('written [%s]...', filename)
-        counter += 1
-
-
-def debug_requests():
-    """
-    Activate the debugging features of the requests module
-    :return:
-    """
-    http.client.HTTPConnection.debuglevel = 1
-    requests_log = logging.getLogger("requests.packages.urllib3")
-    requests_log.propagate = True
-
-
 def add_http(url, main_url):
     """
     add two urls together
@@ -108,13 +65,31 @@ def add_http(url, main_url):
     return urllib.parse.urljoin(main_url, url)
 
 
-def print_element(element):
+def get_element_as_bytes(element):
     """
-    from xml elements from etree
+    turn xml element from etree to bytes
     :param element:
     :return:
     """
-    print(lxml.etree.tostring(element, pretty_print=True).decode())
+    return lxml.etree.tostring(element, pretty_print=True)
+
+
+def get_element_as_string(element):
+    """
+    turn xml element from etree to string
+    :param element:
+    :return:
+    """
+    return lxml.etree.tostring(element, pretty_print=True).decode()
+
+
+def print_element(element):
+    """
+    print xml elements from etree
+    :param element:
+    :return:
+    """
+    print(get_element_as_string(element))
 
 
 def download_url(session, source: str, target: str) -> None:
@@ -128,7 +103,7 @@ def download_url(session, source: str, target: str) -> None:
         return
     try:
         response = session.get(source, stream=True)
-        assert response.status_code == 200, response.content
+        response.raise_for_status()
         with open(target, 'wb') as file_handle:
             response.raw.decode_content = True
             shutil.copyfileobj(response.raw, file_handle)
@@ -160,7 +135,7 @@ def download_video_if_wider(session, source: str, target: str, width: int) -> bo
     try:
         response = session.get(source, stream=True)
         if FAIL:
-            assert response.status_code == 200, response.content
+            response.raise_for_status()
         else:
             if response.status_code != 200:
                 logger.info("got bad error code [%s] and failed to download", response.status_code)
